yt.geometry package
===================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   yt.geometry.coordinates

Submodules
----------

.. toctree::
   :maxdepth: 4

   yt.geometry.api
   yt.geometry.fake_octree
   yt.geometry.fake_octree
   yt.geometry.fake_octree
   yt.geometry.geometry_handler
   yt.geometry.grid_container
   yt.geometry.grid_container
   yt.geometry.grid_container
   yt.geometry.grid_geometry_handler
   yt.geometry.grid_visitors
   yt.geometry.grid_visitors
   yt.geometry.grid_visitors
   yt.geometry.oct_container
   yt.geometry.oct_container
   yt.geometry.oct_container
   yt.geometry.oct_geometry_handler
   yt.geometry.oct_visitors
   yt.geometry.oct_visitors
   yt.geometry.oct_visitors
   yt.geometry.particle_deposit
   yt.geometry.particle_deposit
   yt.geometry.particle_deposit
   yt.geometry.particle_geometry_handler
   yt.geometry.particle_oct_container
   yt.geometry.particle_oct_container
   yt.geometry.particle_oct_container
   yt.geometry.particle_smooth
   yt.geometry.particle_smooth
   yt.geometry.particle_smooth
   yt.geometry.selection_routines
   yt.geometry.selection_routines
   yt.geometry.selection_routines
   yt.geometry.unstructured_mesh_handler

Module contents
---------------

.. automodule:: yt.geometry
   :members:
   :undoc-members:
   :inherited-members:
   :show-inheritance:
